@@ -61,7 +61,8 @@ PROPERTY_CHANGE_MASK     = 1 << 16
 VISIBILITY_NOTIFY_MASK   = 1 << 17
 PROXIMITY_IN_MASK        = 1 << 18
 PROXIMITY_OUT_MASK       = 1 << 19
-ALL_EVENTS_MASK          = 0x07FFFF
+SUBSTRUCTURE_MASK        = 1 << 20
+ALL_EVENTS_MASK          = 0x0FFFFF
 
 # GdkFontType's
 FONT_FONT    = 0
@@ -75,6 +76,11 @@ NOTIFY_NONLINEAR         = 3
 NOTIFY_NONLINEAR_VIRTUAL = 4
 NOTIFY_UNKNOWN           = 5
 
+# GdkCrossingMode's
+CROSSING_NORMAL = 0
+CROSSING_GRAB   = 1
+CROSSING_UNGRAB = 2
+
 # GdkModifierType's
 SHIFT_MASK   = 1 << 0
 LOCK_MASK    = 1 << 1
@@ -89,6 +95,7 @@ BUTTON2_MASK = 1 << 9
 BUTTON3_MASK = 1 << 10
 BUTTON4_MASK = 1 << 11
 BUTTON5_MASK = 1 << 12
+RELEASE_MASK = 1 << 13
 
 # GdkPropertyState's
 PROPERTY_NEW_VALUE = 0
