@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 #
 # Test of gtk.Text widget.
 #
@@ -40,7 +40,7 @@ class Application:
                         ('Edit/Copy',  None, self.process_edit_copy),
                         ('Edit/Paste', None, self.process_edit_paste),
                 ])
-                self.w_window.add_accelerator_table(self.w_menubar.accelerator)
+                self.w_window.add_accel_group(self.w_menubar.accelerator)
                 self.w_vbox.pack_start(self.w_menubar, expand=FALSE)
                 self.w_menubar.show()
 
