@@ -3,7 +3,8 @@
 # translation of "Hello World III" from GTK manual, using gtk_object_new
 # with gtkmodule.  Also implements a tooltip for the button.
 
-from gtk import *
+from _gtk import *
+from _gtkbase import *
 from GTK import *
 
 def hello(*args):
@@ -15,25 +16,26 @@ def destroy(*args):
 	gtk_main_quit()
 
 gtk_init()
+pygtk_init()
 
 tt = gtk_tooltips_new()
 gtk_tooltips_set_delay(tt, 500)
 
 window = gtk_object_new("GtkWindow", {
-	'GtkWindow::type':            WINDOW_TOPLEVEL,
-	'GtkWindow::title':           'Hello World',
-	'GtkWindow::allow_grow':      0,
-	'GtkWindow::allow_shrink':    0,
-	'GtkObject::signal::destroy': destroy,
-	'GtkContainer::border_width': 10
+	'type':         WINDOW_TOPLEVEL,
+	'title':        'Hello World',
+	'allow_grow':   0,
+	'allow_shrink': 0,
+	'border_width': 10
 })
+gtk_signal_connect(window, "destroy", destroy)
 
 button = gtk_object_new("GtkButton", {
-	'GtkButton::label': 'Hello World',
-	'GtkObject::signal::clicked': hello,
-	'GtkWidget::parent': window,
-	'GtkWidget::visible': 1
+	'label':   'Hello World',
+	'parent':  window,
+	'visible': 1
 })
+gtk_signal_connect(button, "clicked", hello)
 
 gtk_tooltips_set_tip(tt, button, 'Prints "Hello World"', '')
 gtk_tooltips_enable(tt)
